pub enum UValue<'value> {
Bool(bool),
Int(i32),
Real(N32),
Array(UArray<'value>),
Tuple(UTuple<'value>),
}Expand description
Value type that has been “unpacked” on its first level
Value is quite opaque in itself due to how its memory representation was designed. To read
its contents, call Value::unpack and pattern-match on the returned UValue.
Unpacked values are only unpacked on the “first level”. For instance, an unpacked tuple will
only reveal that it is a tuple and what its size is, but its field will be packed Values
that will need to be unpacked after (if needed). This makes the entire abstraction
allocation-free.
Note
UValue is supposed to mean “unpacked value” but since we’re goin to pattern match a lot with it, I’d rather make it short to type.
Variants