pub struct Value<T = Type, B = EcoVec<u8>> { /* private fields */ }Expand description
A Lustre value with its type, stored as a compact opaque value
Usage
- Use
Value::type_of()to get the type of the value - Use
Value::unpack()to inspect the contents of the value
Internal representation
Values are usually stored as a tuple of Type × EcoVec<u8>*. The
interpretation of the byte array is directly dependent on the type of the value. The
implementation may use unsafe code that assumes that the byte array has the correct length for a
given type.
*The type is generic over both of these, so you can have a borrowed version of a value
A given type always has a constant size that may be 0. The types respect the following encoding:
Implementations